==> ikapi-3.0.6.tgz: package/src/IKEventProcessor.js <==
import IKTransaction from './BaseEvent/IKTransaction';
import IKResponse, { IKBadRequestResponse, IKSuccessResponse } from './API/IKResponse';
import IKGlobals from './IKGlobals';
//
export default class IKEventProcessor {
  constructor(event, context, config, isBatch) {
    this.event = event;
    this.context = context;
    this.apiConfig = config;
    this.isBatch = isBatch;
  }
  async processEvent(execution, doNotDecodeMessage) {
    const resp = await this._processRawEvent(execution, doNotDecodeMessage);
    if (resp && !(resp.getCode() >= 200 && resp.getCode() < 300)) throw new Error(JSON.stringify(resp.getBody()));
    else if (resp) return resp;
  }
  async _processRawEvent(execution, doNotDecodeMessage) {
    if (this.event.Records && this.event.Records.length > 0) { //safe check for empty events?
      //init transaction for all records
      return await (new IKTransaction(this.event, this.context, this.apiConfig, true /*batch processing*/)).execute(async (transaction) => {
        //Map records with decoded message when required
        const decodedRecords = this.event.Records.map((eventRecord) => (doNotDecodeMessage ? eventRecord.body : JSON.parse(eventRecord.body)));
        //If is batch, return execution 
        if (this.isBatch) return await execution(transaction, decodedRecords);
        //for each available event
        for (let eventRecord of decodedRecords) {
          //Call execution
          let resp = await execution(transaction, eventRecord);
          if (!(resp.getCode() >= 200 && resp.getCode() < 300)) { //if execution failed, respond and mark as answered
            return resp;
          }
        }
        //not errored and loop ended - succeeded
        return IKSuccessResponse();
      });
    } else return IKBadRequestResponse(IKGlobals.ErrorResponseNoRecords, IKGlobals.ErrorCode_NoRecords); //no event to be processed?
  }
}

==> ikapi-3.1.31.tgz: package/src/IKEventProcessor.js <==
import IKTransaction from './BaseEvent/IKTransaction';
import IKResponse, { IKBadRequestResponse, IKSuccessResponse } from './API/IKResponse';
import IKGlobals from './IKGlobals';
//
export default class IKEventProcessor {
  constructor(event, context, config, isBatch) {
    this.event = event;
    this.context = context;
    this.apiConfig = config;
    this._syncReturn = isBatch;
  }
  async processEvent(execution, doNotDecodeMessage) {
    const resp = await this._processRawEvent(execution, doNotDecodeMessage);
    if (resp && !(resp.getCode() >= 200 && resp.getCode() < 300)) throw new Error(JSON.stringify(resp.getBody()));
    else if (resp) return resp;
  }
  async _processRawEvent(execution, doNotDecodeMessage) {
    if (this.event.Records && this.event.Records.length > 0) { //safe check for empty events?
      //init transaction for all records
      return await (new IKTransaction(this.event, this.context, this.apiConfig, true /*batch processing*/)).execute(async (transaction) => {
        //Map records with decoded message when required
        const decodedRecords = this.event.Records.map((eventRecord) => (doNotDecodeMessage ? eventRecord.body : JSON.parse(eventRecord.body)));
        //If is batch, return execution 
        if (this._syncReturn) return await execution(transaction, decodedRecords);
        //for each available event
        for (let eventRecord of decodedRecords) {
          //Call execution
          let resp = await execution(transaction, eventRecord);
          if (!(resp.getCode() >= 200 && resp.getCode() < 300)) { //if execution failed, respond and mark as answered
            return resp;
          }
        }
        //not errored and loop ended - succeeded
        return IKSuccessResponse();
      });
    } else return IKBadRequestResponse(IKGlobals.ErrorResponseNoRecords, IKGlobals.ErrorCode_NoRecords); //no event to be processed?
  }
}
